xserver: Branch 'master'

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Mon Feb 1 09:09:31 UTC 2021


 mi/mibitblt.c |    4 ++--
 mi/micopy.c   |    5 +++--
 2 files changed, 5 insertions(+), 4 deletions(-)

New commits:
commit 5429791b1cf7f6cabf6c64aad0a4b1b5418253c9
Author: Olivier Fourdan <ofourdan at redhat.com>
Date:   Thu Jan 28 17:11:44 2021 +0100

    Revert "mi: Shortcut miDoCopy/miCopyArea based on clipList"
    
    This reverts commit f665a9c9e6c8643f3050378249db3088ae3057be.
    
    Signed-off-by: Olivier Fourdan <ofourdan at redhat.com>
    Acked-by: Martin Peres <martin.peres at mupuf.org>
    Closes: https://gitlab.freedesktop.org/xorg/xserver/-/issues/1108
    Closes: https://gitlab.freedesktop.org/xorg/xserver/-/issues/1128

diff --git a/mi/micopy.c b/mi/micopy.c
index dd40ec0e3..40096f24c 100644
--- a/mi/micopy.c
+++ b/mi/micopy.c
@@ -152,9 +152,10 @@ miDoCopy(DrawablePtr pSrcDrawable,
     Bool fastDst = FALSE;       /* for fast clipping with one rect dest */
     Bool fastExpose = FALSE;    /* for fast exposures with pixmap source */
 
-    /* Short cut for unmapped or fully clipped windows */
+    /* Short cut for unmapped windows */
+
     if (pDstDrawable->type == DRAWABLE_WINDOW &&
-        RegionNil(pGC->pCompositeClip)) {
+        !((WindowPtr) pDstDrawable)->realized) {
         return NULL;
     }
 


More information about the xorg-commit mailing list
diff --git a/mi/mibitblt.c b/mi/mibitblt.c
index 0954b2545..0b13e49e4 100644
--- a/mi/mibitblt.c
+++ b/mi/mibitblt.c
@@ -96,9 +96,9 @@ miCopyArea(DrawablePtr pSrcDrawable,
     srcx = xIn + pSrcDrawable->x;
     srcy = yIn + pSrcDrawable->y;
 
     /* If the destination is clipped away, this is easy */
     if (pDstDrawable->type == DRAWABLE_WINDOW &&
-        RegionNil(pGC->pCompositeClip))
+        !((WindowPtr) pDstDrawable)->realized)
         return NULL;
 
     /* clip the source */
@@ -96,9 +96,9 @@ miCopyArea(DrawablePtr pSrcDrawable,
     srcy = yIn + pSrcDrawable->y;
 
-    /* If the destination is clipped away, this is easy */
+    /* If the destination isn't realized, this is easy */
     if (pDstDrawable->type == DRAWABLE_WINDOW &&